<template>
  <a-card :bordered="false">

    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="设备编号">
              <a-input placeholder="请输入设备编号" v-model="queryParam.equipmentCode"></a-input>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="设备名称">
              <a-input placeholder="请输入设备名称" v-model="queryParam.equipmentName"></a-input>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="关键设备标识">
              <j-dict-select-tag dict-code="yn" placeholder="请选择关键设备标识"
                                 v-model="queryParam.equipmentImportance"></j-dict-select-tag>
            </a-form-item>
          </a-col>
          <template v-if="toggleSearchStatus">
            <a-col :xl="6" :lg="7" :md="8" :sm="24">
              <a-form-item label="资产状态">
                <j-dict-select-tag dict-code="asset_status" placeholder="请选择资产状态"
                                   v-model="queryParam.assetStatus"></j-dict-select-tag>
              </a-form-item>
            </a-col>
            <a-col :xl="6" :lg="7" :md="8" :sm="24">
              <a-form-item label="技术状态">
                <j-dict-select-tag dict-code="technology_status" placeholder="请选择技术状态"
                                   v-model="queryParam.technologyStatus"></j-dict-select-tag>
              </a-form-item>
            </a-col>
            <a-col :xl="6" :lg="7" :md="8" :sm="24">
              <a-form-item label="操作系统">
                <a-input placeholder="请输入操作系统" v-model="queryParam.operationSystem"></a-input>
              </a-form-item>
            </a-col>
            <a-col :xl="6" :lg="7" :md="8" :sm="24">
              <a-form-item label="使用车间">
                <a-tree-select v-model="queryParam.orgId"
                               style="width: 100%"
                               :tree-data="treeData"
                               :dropdown-style="{ maxHeight: '400px', overflow: 'auto' }"
                               placeholder="请选择使用车间"
                               allow-clear
                               tree-default-expand-all
                >
                </a-tree-select>
              </a-form-item>
            </a-col>
            <a-col :xl="6" :lg="7" :md="8" :sm="24">
              <a-form-item label="设备分类">
                <j-dict-select-tag dict-code="equipment_category" placeholder="请选择设备分类"
                                   v-model="queryParam.equipmentCategory"></j-dict-select-tag>
              </a-form-item>
            </a-col>
          </template>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <span style="float: left;overflow: hidden;" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button type="info" @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
              <a @click="handleToggleSearch" style="margin-left: 8px">
                {{ toggleSearchStatus ? '收起' : '展开' }}
                <a-icon :type="toggleSearchStatus ? 'up' : 'down'"/>
              </a>
            </span>
          </a-col>

        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
      <a-button type="primary" icon="download" @click="handleExportXls('设备台账')">导出</a-button>
      <a-upload name="file" :showUploadList="false" :multiple="false" :headers="tokenHeader" :action="importExcelUrl"
                @change="handleImportExcel">
        <a-button type="primary" icon="import">导入</a-button>
      </a-upload>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel">
            <a-icon type="delete"/>
            删除
          </a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作
          <a-icon type="down"/>
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a
        style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :scroll="{ x: 'max-content' }"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange">
        <span slot="equipmentImportance" slot-scope="text">
          <lx-switch v-model="text" disabled checked-children="是" un-checked-children="否"/>
        </span>
        <span slot="mdcFlag" slot-scope="text">
          <lx-switch v-model="text" disabled checked-children="是" un-checked-children="否"/>
        </span>
        <span slot="processParametersFlag" slot-scope="text">
          <lx-switch v-model="text" disabled checked-children="有" un-checked-children="无"/>
        </span>
        <span slot="precisionParametersFlag" slot-scope="text">
          <lx-switch v-model="text" disabled checked-children="有" un-checked-children="无"/>
        </span>
        <span slot="specialEquipment" slot-scope="text">
          <lx-switch v-model="text" disabled checked-children="是" un-checked-children="否"/>
        </span>
        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>

          <a-divider type="vertical"/>
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down"/></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a href="javascript:;" @click="handleOpenNameplateModal(record)">铭牌</a>
              </a-menu-item>
              <a-menu-item>
                <a href="javascript:;" @click="handleDetail(record)">详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>
    <!-- table区域-end -->

    <!-- 表单区域 -->
    <eamEquipment-modal ref="modalForm" @ok="modalFormOk"></eamEquipment-modal>
    <!--铭牌弹窗-->
    <nameplate-modal ref="nameplateModalRef"/>
  </a-card>
</template>

<script>
import '@/assets/less/TableExpand.less'
import EamEquipmentModal from './modules/EamEquipmentModal'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction } from '@api/manage'
import NameplateModal from '@views/eam/equipment/modules/NameplateModal.vue'

export default {
  name: 'EamEquipmentList',
  mixins: [JeecgListMixin],
  components: {
    NameplateModal,
    EamEquipmentModal
  },
  data() {
    return {
      description: '设备台账管理页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          },
          fixed: 'left'
        },
        {
          title: '设备编号',
          align: 'center',
          width: 100,
          dataIndex: 'equipmentCode',
          ellipsis: true,
          fixed: 'left',
          sorter: true
        },
        {
          title: '设备名称',
          align: 'center',
          width: 100,
          dataIndex: 'equipmentName',
          ellipsis: true,
          fixed: 'left'
        },
        {
          title: '关键设备标识',
          align: 'center',
          width: 120,
          dataIndex: 'equipmentImportance',
          scopedSlots: { customRender: 'equipmentImportance' }
        },
        {
          title: '资产状态',
          align: 'center',
          width: 100,
          dataIndex: 'assetStatus_dictText'
        },
        {
          title: '技术状态',
          align: 'center',
          width: 100,
          dataIndex: 'technologyStatus_dictText'
        },
        {
          title: '维修状态',
          align: 'center',
          width: 100,
          dataIndex: 'repairStatus_dictText'
        },
        {
          title: '保养状态',
          align: 'center',
          width: 100,
          dataIndex: 'maintenanceStatus_dictText'
        },
        {
          title: '操作系统',
          align: 'center',
          width: 100,
          dataIndex: 'operationSystem'
        },
        {
          title: '使用车间',
          align: 'center',
          width: 100,
          dataIndex: 'orgId_dictText'
        },
        {
          title: '设备管理员',
          align: 'center',
          width: 100,
          dataIndex: 'equipmentManager_dictText'
        },
        {
          title: '设备分类',
          align: 'center',
          width: 100,
          dataIndex: 'equipmentCategory_dictText'
        },
        {
          title: '设备型号',
          align: 'center',
          width: 100,
          dataIndex: 'equipmentModel'
        },
        {
          title: '设备规格',
          align: 'center',
          width: 100,
          dataIndex: 'equipmentSpecification'
        },
        {
          title: '主轴连接尺寸',
          align: 'center',
          width: 120,
          dataIndex: 'spindleConnectDimension'
        },
        {
          title: '总功率',
          align: 'center',
          width: 100,
          dataIndex: 'equipmentPower'
        },
        {
          title: '安装位置',
          align: 'center',
          width: 100,
          dataIndex: 'installationPosition'
        },

        {
          title: '立项卡号',
          align: 'center',
          width: 100,
          dataIndex: 'cardNumber'
        },
        {
          title: '出厂编号',
          align: 'center',
          width: 100,
          dataIndex: 'factoryNumber'
        },
        {
          title: '机床厂家',
          align: 'center',
          width: 100,
          dataIndex: 'manufacturingEnterprise'
        },
        {
          title: '来源国家',
          align: 'center',
          width: 100,
          dataIndex: 'originCountry'
        },
        {
          title: '出厂日期',
          align: 'center',
          width: 100,
          dataIndex: 'leaveFactoryDate'
        },
        {
          title: '验收日期',
          align: 'center',
          width: 100,
          dataIndex: 'acceptanceCheckDate'
        },
        {
          title: '质保开始日期',
          align: 'center',
          width: 120,
          dataIndex: 'warrantyStartDate'
        },
        {
          title: '质保结束日期',
          align: 'center',
          width: 120,
          dataIndex: 'warrantyEndDate'
        },
        {
          title: '是否实施MDC',
          align: 'center',
          width: 120,
          dataIndex: 'mdcFlag',
          scopedSlots: { customRender: 'mdcFlag' }
        },
        {
          title: '有无工艺参数',
          align: 'center',
          width: 120,
          dataIndex: 'processParametersFlag',
          scopedSlots: { customRender: 'processParametersFlag' }
        },
        {
          title: '有无精度参数',
          align: 'center',
          width: 120,
          dataIndex: 'precisionParametersFlag',
          scopedSlots: { customRender: 'precisionParametersFlag' }
        },
        {
          title: '是否为特种设备',
          align: 'center',
          width: 120,
          dataIndex: 'specialEquipment',
          scopedSlots: { customRender: 'specialEquipment' }
        },
        {
          title: '重量',
          align: 'center',
          dataIndex: 'equipmentWeight'
        },
        {
          title: '设备端口',
          align: 'center',
          width: 100,
          dataIndex: 'equipmentPort'
        },
        {
          title: '坐标数量',
          align: 'center',
          width: 100,
          dataIndex: 'coordinateNum'
        },
        {
          title: '备注',
          align: 'center',
          width: 100,
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          width: 150,
          scopedSlots: { customRender: 'action' },
          fixed: 'right'
        }
      ],
      url: {
        list: '/eam/equipment/list',
        delete: '/eam/equipment/delete',
        deleteBatch: '/eam/equipment/deleteBatch',
        exportXlsUrl: 'eam/equipment/exportXls',
        importExcelUrl: 'eam/equipment/importExcel',
        loadProductionOptions: '/mdc/mdcProduction/loadProductionTreeOptions'
      },
      treeData: []
    }
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  created() {
    this.loadAllProductionTree()
  },
  methods: {
    loadAllProductionTree() {
      //加载车间选择树
      getAction(this.url.loadProductionOptions).then(res => {
        if (res.success) {
          this.treeData = [...res.result]
        } else {
          that.$message.warning(res.message)
        }
      })
    },

    /**
     * 开启铭牌弹窗
     * @param record
     */
    handleOpenNameplateModal(record) {
      this.$refs.nameplateModalRef.model = Object.assign({}, record)
      this.$refs.nameplateModalRef.httpUrl = 'http://www.baidu.com'
      this.$refs.nameplateModalRef.visible = true

    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>